==> video_toolbox-1.0.0.tar.gz: video_toolbox/src/Controller/VideoToolBoxReportController.php <==
<?php

namespace Drupal\video_toolbox\Controller;

use Drupal\Core\Url;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\video_toolbox\VideoHandlerInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for videos list report.
 */
class VideoToolBoxReportController extends ControllerBase {

  /**
   * Video Handler Service.
   *
   * @var \Drupal\video_toolbox\VideoHandlerInterface
   */
  protected $videoHandler;

  /**
   * The VideoToolBoxReportController constructor.
   *
   * @param \Drupal\video_toolbox\VideoHandlerInterface $videoHandler
   *   The videoHandler service helps with video management.
   */
  public function __construct(VideoHandlerInterface $videoHandler) {
    $this->videoHandler = $videoHandler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('video.get_service'));
  }

  /**
   * Type of the video identifier.
   */
  const VIDEO_IDENTIFIER_TYPE = 'video_id';

  /**
   * Creates the report page.
   *
   * @return array
   *   Render array for report output.
   */
  public function report() {
    $content = [];

    $content['add'] = [
      '#type' => 'link',
      '#title' => $this->t('Add video'),
      '#attributes' => [
        'class' => ['button button--primary'],
      ],
      '#url' => Url::fromRoute('video_toolbox.form'),
    ];

    $content['message'] = [
      '#markup' => '<br>' . $this->t('Below is a list of all uploaded videos including user, video description, video format, video link and video upload date.'),
    ];

    $headers = [
      $this->t('User'),
      $this->t('Description'),
      $this->t('Link'),
      $this->t('Uploaded date'),
      $this->t('Format'),
      $this->t('Download'),
    ];
    $videos = $this->videoHandler->getVideosInfo();
    $rows = [];

    foreach ($videos as $entry) {
      // Cuts the description short in case it is too long for the table.
      if (strlen($entry['description']) > 20) {
        $entry['description'] = substr($entry['description'], 0, 20) . '...';
      }
      // Obtains URLs from given routes.
      $url = Url::fromRoute('video_toolbox.videos_url', ['video_id' => $entry['video_key']])->toString();
      $urlDownload = Url::fromRoute('video_toolbox.download', [
        'identifier' => $entry['video_key'],
        'type' => self::VIDEO_IDENTIFIER_TYPE,
      ])->toString();
      $rows[] = [
        $entry['name'],
        $entry['description'],
        new FormattableMarkup('<a href=":link">@name</a>',
        [
          ':link' => $url,
          '@name' => $entry['filename'],
        ]),
        date("d/m/Y", $entry['upload_date']),
        $entry['filemime'],
        new TranslatableMarkup('<a class="button button--primary" href=":link">@download</a>',
          [
            ':link' => $urlDownload,
            '@download' => 'Download',
          ]
        ),
      ];
    }
    $content['table'] = [
      '#type' => 'table',
      '#header' => $headers,
      '#rows' => $rows,
      '#empty' => $this->t('No entries available'),
    ];
    // Don't cache this page.
    $content['#cache']['max-age'] = 0;
    return $content;
  }

}

==> video_toolbox-1.0.1.tar.gz: video_toolbox/src/Controller/VideoToolBoxReportController.php <==
<?php

namespace Drupal\video_toolbox\Controller;

use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Url;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\video_toolbox\Traits\VideoFormDependencyInjectionTrait;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Controller for videos list report.
 */
class VideoToolBoxReportController extends ControllerBase {

  use VideoFormDependencyInjectionTrait;


  /**
   * Type of the video identifier.
   */
  const VIDEO_IDENTIFIER_TYPE = 'video_id';

  /**
   * Creates the report page.
   *
   * @return array
   *   Render array for report output.
   */
  public function report(Request $request) {

    $roles = $this->account->getRoles();

    $uid = $this->account->id();

    $permissions = $this->account->hasPermission('upload_content_videos');

    $content = [];

    $user = $request->query->all();

    if ($permissions) {
      $content['add'] = [
        '#type' => 'link',
        '#title' => $this->t('Add video'),
        '#attributes' => [
          'class' => ['button button--primary'],
        ],
        '#url' => Url::fromRoute('video_toolbox.form'),
      ];
    }

    $content['message'] = [
      '#markup' => '<br>' . $this->t('Below is a list of all uploaded videos including user, video description, video format, video link and video upload date.'),
    ];

    $headers = [
      $this->t('User'),
      $this->t('Description'),
      $this->t('Link'),
      $this->t('Uploaded date'),
      $this->t('Format'),
      $this->t('Download'),
    ];

    if (!$user) {
      $user['user'] = NULL;
    }

    if (array_search("administrator", $roles)) {
      $uid = NULL ?? $user['user'];
      $form = $this->formBuilder()->getForm('\Drupal\video_toolbox\Form\VideoSearchForm');
      $content['search'] = $form;
    }

    if (!array_search("administrator", $roles)) {
      $user['user'] = $uid;
    }

    if ($user) {
      $uid = $user['user'];
    }

    if (is_string($uid) && $uid == "") {
      return new RedirectResponse("/");
    }

    $videos = $this->videoHandler->getVideosInfo($uid);
    $rows = [];

    foreach ($videos as $entry) {
      // Cuts the description short in case it is too long for the table.
      if (strlen($entry['description']) > 20) {
        $entry['description'] = substr($entry['description'], 0, 20) . '...';
      }
      // Obtains URLs from given routes.
      $url = Url::fromRoute('video_toolbox.videos_url', ['video_id' => $entry['video_key']])->toString();
      $urlDownload = Url::fromRoute('video_toolbox.download', [
        'identifier' => $entry['video_key'],
        'type' => self::VIDEO_IDENTIFIER_TYPE,
      ])->toString();
      $rows[] = [
        $entry['name'],
        $entry['description'],
        new FormattableMarkup('<a href=":link">@name</a>',
        [
          ':link' => $url,
          '@name' => $entry['filename'],
        ]),
        date("d/m/Y", $entry['upload_date']),
        $entry['filemime'],
        new TranslatableMarkup('<a class="button button--primary" href=":link">@download</a>',
        [
          ':link' => $urlDownload,
          '@download' => 'Download',
        ]
        ),
      ];
    }
    $content['table'] = [
      '#type' => 'table',
      '#header' => $headers,
      '#rows' => $rows,
      '#empty' => $this->t('No entries available'),
    ];
    // Don't cache this page.
    $content['#cache']['max-age'] = 0;
    return $content;
  }

}
